from fastapi import APIRouter, HTTPException, status, Depends
from sqlalchemy.orm import Session

from core.database import get_db
from schemas.contactform import ContactFormCreate, ContactFormSchema
from helpers.contactform_helpers import (
    validate_contact_form_data, 
    create_contact_form, 
    format_validation_error_response, 
    send_notification_email
)

router = APIRouter()

@router.post("/email2", status_code=status.HTTP_201_CREATED, response_model=ContactFormSchema)
async def submit_contact_form(
    form_data: ContactFormCreate,
    db: Session = Depends(get_db)
):
    """
    Submit a contact form with name, email, and message.
    
    All fields are required and email must be in valid format.
    """
    # Validate the form data
    validation_errors = validate_contact_form_data(form_data.dict())
    
    if validation_errors:
        error_response = format_validation_error_response(validation_errors)
        raise HTTPException(
            status_code=status.HTTP_400_BAD_REQUEST,
            detail=error_response
        )
    
    # Create the contact form in the database
    contact_form = create_contact_form(db=db, form_data=form_data)
    
    # Send notification email (non-blocking)
    send_notification_email(contact_form)
    
    return contact_form